@@ -50,21 +50,21 @@ var menudata={children:[
 {text:"w",url:"namespacemembers_w.html#index_w"}]},
 {text:"Functions",url:"namespacemembers_func.html",children:[
 {text:"a",url:"namespacemembers_func.html#index_a"},
-{text:"b",url:"namespacemembers_func.html#index_b"},
-{text:"c",url:"namespacemembers_func.html#index_c"},
-{text:"d",url:"namespacemembers_func.html#index_d"},
-{text:"e",url:"namespacemembers_func.html#index_e"},
-{text:"g",url:"namespacemembers_func.html#index_g"},
-{text:"i",url:"namespacemembers_func.html#index_i"},
-{text:"l",url:"namespacemembers_func.html#index_l"},
-{text:"m",url:"namespacemembers_func.html#index_m"},
-{text:"o",url:"namespacemembers_func.html#index_o"},
-{text:"p",url:"namespacemembers_func.html#index_p"},
-{text:"q",url:"namespacemembers_func.html#index_q"},
-{text:"r",url:"namespacemembers_func.html#index_r"},
-{text:"s",url:"namespacemembers_func.html#index_s"},
-{text:"t",url:"namespacemembers_func.html#index_t"},
-{text:"w",url:"namespacemembers_func.html#index_w"}]},
+{text:"b",url:"namespacemembers_func_b.html#index_b"},
+{text:"c",url:"namespacemembers_func_c.html#index_c"},
+{text:"d",url:"namespacemembers_func_d.html#index_d"},
+{text:"e",url:"namespacemembers_func_e.html#index_e"},
+{text:"g",url:"namespacemembers_func_g.html#index_g"},
+{text:"i",url:"namespacemembers_func_i.html#index_i"},
+{text:"l",url:"namespacemembers_func_l.html#index_l"},
+{text:"m",url:"namespacemembers_func_m.html#index_m"},
+{text:"o",url:"namespacemembers_func_o.html#index_o"},
+{text:"p",url:"namespacemembers_func_p.html#index_p"},
+{text:"q",url:"namespacemembers_func_q.html#index_q"},
+{text:"r",url:"namespacemembers_func_r.html#index_r"},
+{text:"s",url:"namespacemembers_func_s.html#index_s"},
+{text:"t",url:"namespacemembers_func_t.html#index_t"},
+{text:"w",url:"namespacemembers_func_w.html#index_w"}]},
 {text:"Variables",url:"namespacemembers_vars.html"},
 {text:"Typedefs",url:"namespacemembers_type.html"},
 {text:"Enumerations",url:"namespacemembers_enum.html"},
@@ -161,7 +161,7 @@ var menudata={children:[
 {text:"s",url:"functions_eval.html#index_s"},
 {text:"u",url:"functions_eval.html#index_u"},
 {text:"v",url:"functions_eval.html#index_v"}]},
-{text:"Related Functions",url:"functions_rela.html",children:[
+{text:"Related Symbols",url:"functions_rela.html",children:[
 {text:"c",url:"functions_rela.html#index_c"},
 {text:"d",url:"functions_rela.html#index_d"},
 {text:"i",url:"functions_rela.html#index_i"},
