@@ -143,7 +143,7 @@ var searchData=
   ['charttypemanager_2eidl_140',['ChartTypeManager.idl',['../ChartTypeManager_8idl.html',1,'']]],
   ['charttypetemplate_2eidl_141',['ChartTypeTemplate.idl',['../ChartTypeTemplate_8idl.html',1,'']]],
   ['chartype_2eidl_142',['CharType.idl',['../CharType_8idl.html',1,'']]],
-  ['checkbox_2eidl_143',['CheckBox.idl',['../component_2CheckBox_8idl.html',1,'(Global Namespace)'],['../control_2CheckBox_8idl.html',1,'(Global Namespace)']]],
+  ['checkbox_2eidl_143',['CheckBox.idl',['../control_2CheckBox_8idl.html',1,'(Global Namespace)'],['../component_2CheckBox_8idl.html',1,'(Global Namespace)']]],
   ['checkinargument_2eidl_144',['CheckinArgument.idl',['../CheckinArgument_8idl.html',1,'']]],
   ['checkoption_2eidl_145',['CheckOption.idl',['../CheckOption_8idl.html',1,'']]],
   ['cipherid_2eidl_146',['CipherID.idl',['../CipherID_8idl.html',1,'']]],
@@ -161,7 +161,7 @@ var searchData=
   ['cmisversion_2eidl_158',['CmisVersion.idl',['../CmisVersion_8idl.html',1,'']]],
   ['collator_2eidl_159',['Collator.idl',['../Collator_8idl.html',1,'']]],
   ['collatoroptions_2eidl_160',['CollatorOptions.idl',['../CollatorOptions_8idl.html',1,'']]],
-  ['color_2eidl_161',['Color.idl',['../rendering_2Color_8idl.html',1,'(Global Namespace)'],['../util_2Color_8idl.html',1,'(Global Namespace)']]],
+  ['color_2eidl_161',['Color.idl',['../util_2Color_8idl.html',1,'(Global Namespace)'],['../rendering_2Color_8idl.html',1,'(Global Namespace)']]],
   ['colorcomponent_2eidl_162',['ColorComponent.idl',['../ColorComponent_8idl.html',1,'']]],
   ['colorcomponenttag_2eidl_163',['ColorComponentTag.idl',['../ColorComponentTag_8idl.html',1,'']]],
   ['colormode_2eidl_164',['ColorMode.idl',['../ColorMode_8idl.html',1,'']]],
@@ -170,48 +170,48 @@ var searchData=
   ['colorscale_2eidl_167',['ColorScale.idl',['../ColorScale_8idl.html',1,'']]],
   ['colorscaleentrytype_2eidl_168',['ColorScaleEntryType.idl',['../ColorScaleEntryType_8idl.html',1,'']]],
   ['colorspacetype_2eidl_169',['ColorSpaceType.idl',['../ColorSpaceType_8idl.html',1,'']]],
-  ['colortable_2eidl_170',['ColorTable.idl',['../ColorTable_8idl.html',1,'']]],
-  ['column_2eidl_171',['Column.idl',['../sdbcx_2Column_8idl.html',1,'(Global Namespace)'],['../sdb_2Column_8idl.html',1,'(Global Namespace)']]],
-  ['columndescriptor_2eidl_172',['ColumnDescriptor.idl',['../ColumnDescriptor_8idl.html',1,'']]],
-  ['columndescriptorcontrol_2eidl_173',['ColumnDescriptorControl.idl',['../ColumnDescriptorControl_8idl.html',1,'']]],
-  ['columndescriptorcontrolmodel_2eidl_174',['ColumnDescriptorControlModel.idl',['../ColumnDescriptorControlModel_8idl.html',1,'']]],
-  ['columnsearch_2eidl_175',['ColumnSearch.idl',['../ColumnSearch_8idl.html',1,'']]],
-  ['columnseparatorstyle_2eidl_176',['ColumnSeparatorStyle.idl',['../ColumnSeparatorStyle_8idl.html',1,'']]],
-  ['columnsettings_2eidl_177',['ColumnSettings.idl',['../ColumnSettings_8idl.html',1,'']]],
-  ['columntype_2eidl_178',['ColumnType.idl',['../ColumnType_8idl.html',1,'']]],
-  ['columnvalue_2eidl_179',['ColumnValue.idl',['../ColumnValue_8idl.html',1,'']]],
-  ['combinedcharacters_2eidl_180',['CombinedCharacters.idl',['../CombinedCharacters_8idl.html',1,'']]],
-  ['combobox_2eidl_181',['ComboBox.idl',['../component_2ComboBox_8idl.html',1,'(Global Namespace)'],['../control_2ComboBox_8idl.html',1,'(Global Namespace)']]],
-  ['command_2eidl_182',['Command.idl',['../awt_2Command_8idl.html',1,'(Global Namespace)'],['../animations_2Command_8idl.html',1,'(Global Namespace)'],['../ucb_2Command_8idl.html',1,'(Global Namespace)']]],
-  ['commandabortedexception_2eidl_183',['CommandAbortedException.idl',['../CommandAbortedException_8idl.html',1,'']]],
-  ['commandbutton_2eidl_184',['CommandButton.idl',['../control_2CommandButton_8idl.html',1,'(Global Namespace)'],['../component_2CommandButton_8idl.html',1,'(Global Namespace)']]],
-  ['commanddefinition_2eidl_185',['CommandDefinition.idl',['../CommandDefinition_8idl.html',1,'']]],
-  ['commandenvironment_2eidl_186',['CommandEnvironment.idl',['../CommandEnvironment_8idl.html',1,'']]],
-  ['commandfailedexception_2eidl_187',['CommandFailedException.idl',['../CommandFailedException_8idl.html',1,'']]],
-  ['commandgroup_2eidl_188',['CommandGroup.idl',['../CommandGroup_8idl.html',1,'']]],
-  ['commandinfo_2eidl_189',['CommandInfo.idl',['../CommandInfo_8idl.html',1,'']]],
-  ['commandinfochange_2eidl_190',['CommandInfoChange.idl',['../CommandInfoChange_8idl.html',1,'']]],
-  ['commandinfochangeevent_2eidl_191',['CommandInfoChangeEvent.idl',['../CommandInfoChangeEvent_8idl.html',1,'']]],
-  ['commandtype_2eidl_192',['CommandType.idl',['../CommandType_8idl.html',1,'']]],
-  ['commonfilepickerelementids_2eidl_193',['CommonFilePickerElementIds.idl',['../CommonFilePickerElementIds_8idl.html',1,'']]],
-  ['comparebookmark_2eidl_194',['CompareBookmark.idl',['../CompareBookmark_8idl.html',1,'']]],
-  ['complexreference_2eidl_195',['ComplexReference.idl',['../ComplexReference_8idl.html',1,'']]],
-  ['componentchangeevent_2eidl_196',['ComponentChangeEvent.idl',['../ComponentChangeEvent_8idl.html',1,'']]],
-  ['components_2eidl_197',['Components.idl',['../Components_8idl.html',1,'']]],
-  ['compositeoperation_2eidl_198',['CompositeOperation.idl',['../CompositeOperation_8idl.html',1,'']]],
-  ['compositiontype_2eidl_199',['CompositionType.idl',['../CompositionType_8idl.html',1,'']]],
-  ['conditionalformat_2eidl_200',['ConditionalFormat.idl',['../ConditionalFormat_8idl.html',1,'']]],
-  ['conditionaltext_2eidl_201',['ConditionalText.idl',['../ConditionalText_8idl.html',1,'']]],
-  ['conditionentrytype_2eidl_202',['ConditionEntryType.idl',['../ConditionEntryType_8idl.html',1,'']]],
-  ['conditionformatentry_2eidl_203',['ConditionFormatEntry.idl',['../ConditionFormatEntry_8idl.html',1,'']]],
-  ['conditionformatoperator_2eidl_204',['ConditionFormatOperator.idl',['../ConditionFormatOperator_8idl.html',1,'']]],
-  ['conditionoperator_2eidl_205',['ConditionOperator.idl',['../ConditionOperator_8idl.html',1,'']]],
-  ['conditionoperator2_2eidl_206',['ConditionOperator2.idl',['../ConditionOperator2_8idl.html',1,'']]],
-  ['configurableuielement_2eidl_207',['ConfigurableUIElement.idl',['../ConfigurableUIElement_8idl.html',1,'']]],
-  ['configuration_2eidl_208',['Configuration.idl',['../Configuration_8idl.html',1,'']]],
-  ['configurationaccess_2eidl_209',['ConfigurationAccess.idl',['../ConfigurationAccess_8idl.html',1,'']]],
-  ['configurationchangeevent_2eidl_210',['ConfigurationChangeEvent.idl',['../ConfigurationChangeEvent_8idl.html',1,'']]],
-  ['configurationcontroller_2eidl_211',['ConfigurationController.idl',['../ConfigurationController_8idl.html',1,'']]],
+  ['colorstop_2eidl_170',['ColorStop.idl',['../ColorStop_8idl.html',1,'']]],
+  ['colorstopsequence_2eidl_171',['ColorStopSequence.idl',['../ColorStopSequence_8idl.html',1,'']]],
+  ['colortable_2eidl_172',['ColorTable.idl',['../ColorTable_8idl.html',1,'']]],
+  ['column_2eidl_173',['Column.idl',['../sdbcx_2Column_8idl.html',1,'(Global Namespace)'],['../sdb_2Column_8idl.html',1,'(Global Namespace)']]],
+  ['columndescriptor_2eidl_174',['ColumnDescriptor.idl',['../ColumnDescriptor_8idl.html',1,'']]],
+  ['columndescriptorcontrol_2eidl_175',['ColumnDescriptorControl.idl',['../ColumnDescriptorControl_8idl.html',1,'']]],
+  ['columndescriptorcontrolmodel_2eidl_176',['ColumnDescriptorControlModel.idl',['../ColumnDescriptorControlModel_8idl.html',1,'']]],
+  ['columnsearch_2eidl_177',['ColumnSearch.idl',['../ColumnSearch_8idl.html',1,'']]],
+  ['columnseparatorstyle_2eidl_178',['ColumnSeparatorStyle.idl',['../ColumnSeparatorStyle_8idl.html',1,'']]],
+  ['columnsettings_2eidl_179',['ColumnSettings.idl',['../ColumnSettings_8idl.html',1,'']]],
+  ['columntype_2eidl_180',['ColumnType.idl',['../ColumnType_8idl.html',1,'']]],
+  ['columnvalue_2eidl_181',['ColumnValue.idl',['../ColumnValue_8idl.html',1,'']]],
+  ['combinedcharacters_2eidl_182',['CombinedCharacters.idl',['../CombinedCharacters_8idl.html',1,'']]],
+  ['combobox_2eidl_183',['ComboBox.idl',['../control_2ComboBox_8idl.html',1,'(Global Namespace)'],['../component_2ComboBox_8idl.html',1,'(Global Namespace)']]],
+  ['command_2eidl_184',['Command.idl',['../awt_2Command_8idl.html',1,'(Global Namespace)'],['../animations_2Command_8idl.html',1,'(Global Namespace)'],['../ucb_2Command_8idl.html',1,'(Global Namespace)']]],
+  ['commandabortedexception_2eidl_185',['CommandAbortedException.idl',['../CommandAbortedException_8idl.html',1,'']]],
+  ['commandbutton_2eidl_186',['CommandButton.idl',['../control_2CommandButton_8idl.html',1,'(Global Namespace)'],['../component_2CommandButton_8idl.html',1,'(Global Namespace)']]],
+  ['commanddefinition_2eidl_187',['CommandDefinition.idl',['../CommandDefinition_8idl.html',1,'']]],
+  ['commandenvironment_2eidl_188',['CommandEnvironment.idl',['../CommandEnvironment_8idl.html',1,'']]],
+  ['commandfailedexception_2eidl_189',['CommandFailedException.idl',['../CommandFailedException_8idl.html',1,'']]],
+  ['commandgroup_2eidl_190',['CommandGroup.idl',['../CommandGroup_8idl.html',1,'']]],
+  ['commandinfo_2eidl_191',['CommandInfo.idl',['../CommandInfo_8idl.html',1,'']]],
+  ['commandinfochange_2eidl_192',['CommandInfoChange.idl',['../CommandInfoChange_8idl.html',1,'']]],
+  ['commandinfochangeevent_2eidl_193',['CommandInfoChangeEvent.idl',['../CommandInfoChangeEvent_8idl.html',1,'']]],
+  ['commandtype_2eidl_194',['CommandType.idl',['../CommandType_8idl.html',1,'']]],
+  ['commonfilepickerelementids_2eidl_195',['CommonFilePickerElementIds.idl',['../CommonFilePickerElementIds_8idl.html',1,'']]],
+  ['comparebookmark_2eidl_196',['CompareBookmark.idl',['../CompareBookmark_8idl.html',1,'']]],
+  ['complexreference_2eidl_197',['ComplexReference.idl',['../ComplexReference_8idl.html',1,'']]],
+  ['componentchangeevent_2eidl_198',['ComponentChangeEvent.idl',['../ComponentChangeEvent_8idl.html',1,'']]],
+  ['components_2eidl_199',['Components.idl',['../Components_8idl.html',1,'']]],
+  ['compositeoperation_2eidl_200',['CompositeOperation.idl',['../CompositeOperation_8idl.html',1,'']]],
+  ['compositiontype_2eidl_201',['CompositionType.idl',['../CompositionType_8idl.html',1,'']]],
+  ['conditionalformat_2eidl_202',['ConditionalFormat.idl',['../ConditionalFormat_8idl.html',1,'']]],
+  ['conditionaltext_2eidl_203',['ConditionalText.idl',['../ConditionalText_8idl.html',1,'']]],
+  ['conditionentrytype_2eidl_204',['ConditionEntryType.idl',['../ConditionEntryType_8idl.html',1,'']]],
+  ['conditionformatentry_2eidl_205',['ConditionFormatEntry.idl',['../ConditionFormatEntry_8idl.html',1,'']]],
+  ['conditionformatoperator_2eidl_206',['ConditionFormatOperator.idl',['../ConditionFormatOperator_8idl.html',1,'']]],
+  ['conditionoperator_2eidl_207',['ConditionOperator.idl',['../ConditionOperator_8idl.html',1,'']]],
+  ['conditionoperator2_2eidl_208',['ConditionOperator2.idl',['../ConditionOperator2_8idl.html',1,'']]],
+  ['configurableuielement_2eidl_209',['ConfigurableUIElement.idl',['../ConfigurableUIElement_8idl.html',1,'']]],
+  ['configurationaccess_2eidl_210',['ConfigurationAccess.idl',['../ConfigurationAccess_8idl.html',1,'']]],
+  ['configurationchangeevent_2eidl_211',['ConfigurationChangeEvent.idl',['../ConfigurationChangeEvent_8idl.html',1,'']]],
   ['configurationevent_2eidl_212',['ConfigurationEvent.idl',['../ConfigurationEvent_8idl.html',1,'']]],
   ['configurationprovider_2eidl_213',['ConfigurationProvider.idl',['../ConfigurationProvider_8idl.html',1,'']]],
   ['configurationregistry_2eidl_214',['ConfigurationRegistry.idl',['../ConfigurationRegistry_8idl.html',1,'']]],
@@ -293,7 +293,7 @@ var searchData=
   ['cryptographyexception_2eidl_290',['CryptographyException.idl',['../CryptographyException_8idl.html',1,'']]],
   ['csvlogformatter_2eidl_291',['CsvLogFormatter.idl',['../CsvLogFormatter_8idl.html',1,'']]],
   ['ctlscripttype_2eidl_292',['CTLScriptType.idl',['../CTLScriptType_8idl.html',1,'']]],
-  ['currency_2eidl_293',['Currency.idl',['../offapi_2com_2sun_2star_2i18n_2Currency_8idl.html',1,'(Global Namespace)'],['../udkapi_2com_2sun_2star_2bridge_2oleautomation_2Currency_8idl.html',1,'(Global Namespace)']]],
+  ['currency_2eidl_293',['Currency.idl',['../udkapi_2com_2sun_2star_2bridge_2oleautomation_2Currency_8idl.html',1,'(Global Namespace)'],['../offapi_2com_2sun_2star_2i18n_2Currency_8idl.html',1,'(Global Namespace)']]],
   ['currency2_2eidl_294',['Currency2.idl',['../Currency2_8idl.html',1,'']]],
   ['currencyfield_2eidl_295',['CurrencyField.idl',['../control_2CurrencyField_8idl.html',1,'(Global Namespace)'],['../component_2CurrencyField_8idl.html',1,'(Global Namespace)']]],
   ['curvestyle_2eidl_296',['CurveStyle.idl',['../CurveStyle_8idl.html',1,'']]],
