@@ -224,7 +224,7 @@ var searchData=
   ['documentrevisionlistpersistence_2eidl_221',['DocumentRevisionListPersistence.idl',['../DocumentRevisionListPersistence_8idl.html',1,'']]],
   ['documentsaverequest_2eidl_222',['DocumentSaveRequest.idl',['../DocumentSaveRequest_8idl.html',1,'']]],
   ['documentscriptlibrarycontainer_2eidl_223',['DocumentScriptLibraryContainer.idl',['../DocumentScriptLibraryContainer_8idl.html',1,'']]],
-  ['documentsettings_2eidl_224',['DocumentSettings.idl',['../presentation_2DocumentSettings_8idl.html',1,'(Global Namespace)'],['../sheet_2DocumentSettings_8idl.html',1,'(Global Namespace)'],['../drawing_2DocumentSettings_8idl.html',1,'(Global Namespace)'],['../text_2DocumentSettings_8idl.html',1,'(Global Namespace)']]],
+  ['documentsettings_2eidl_224',['DocumentSettings.idl',['../text_2DocumentSettings_8idl.html',1,'(Global Namespace)'],['../sheet_2DocumentSettings_8idl.html',1,'(Global Namespace)'],['../presentation_2DocumentSettings_8idl.html',1,'(Global Namespace)'],['../drawing_2DocumentSettings_8idl.html',1,'(Global Namespace)']]],
   ['documentsignatureinformation_2eidl_225',['DocumentSignatureInformation.idl',['../DocumentSignatureInformation_8idl.html',1,'']]],
   ['documentstatistic_2eidl_226',['DocumentStatistic.idl',['../DocumentStatistic_8idl.html',1,'']]],
   ['documentstoremode_2eidl_227',['DocumentStoreMode.idl',['../DocumentStoreMode_8idl.html',1,'']]],
@@ -246,7 +246,7 @@ var searchData=
   ['drawpage_2eidl_243',['DrawPage.idl',['../presentation_2DrawPage_8idl.html',1,'(Global Namespace)'],['../drawing_2DrawPage_8idl.html',1,'(Global Namespace)']]],
   ['drawpages_2eidl_244',['DrawPages.idl',['../DrawPages_8idl.html',1,'']]],
   ['drawviewmode_2eidl_245',['DrawViewMode.idl',['../DrawViewMode_8idl.html',1,'']]],
-  ['driver_2eidl_246',['Driver.idl',['../sdbc_2Driver_8idl.html',1,'(Global Namespace)'],['../sdbcx_2Driver_8idl.html',1,'(Global Namespace)']]],
+  ['driver_2eidl_246',['Driver.idl',['../sdbcx_2Driver_8idl.html',1,'(Global Namespace)'],['../sdbc_2Driver_8idl.html',1,'(Global Namespace)']]],
   ['drivermanager_2eidl_247',['DriverManager.idl',['../DriverManager_8idl.html',1,'']]],
   ['driverpropertyinfo_2eidl_248',['DriverPropertyInfo.idl',['../DriverPropertyInfo_8idl.html',1,'']]],
   ['dropcapformat_2eidl_249',['DropCapFormat.idl',['../DropCapFormat_8idl.html',1,'']]],
@@ -255,10 +255,11 @@ var searchData=
   ['droptargetdragevent_2eidl_252',['DropTargetDragEvent.idl',['../DropTargetDragEvent_8idl.html',1,'']]],
   ['droptargetdropevent_2eidl_253',['DropTargetDropEvent.idl',['../DropTargetDropEvent_8idl.html',1,'']]],
   ['droptargetevent_2eidl_254',['DropTargetEvent.idl',['../DropTargetEvent_8idl.html',1,'']]],
-  ['duplexmode_2eidl_255',['DuplexMode.idl',['../DuplexMode_8idl.html',1,'']]],
-  ['duplicatecommandidentifierexception_2eidl_256',['DuplicateCommandIdentifierException.idl',['../DuplicateCommandIdentifierException_8idl.html',1,'']]],
-  ['duplicateproviderexception_2eidl_257',['DuplicateProviderException.idl',['../DuplicateProviderException_8idl.html',1,'']]],
-  ['duration_2eidl_258',['Duration.idl',['../Duration_8idl.html',1,'']]],
-  ['dynamic_2eidl_259',['Dynamic.idl',['../Dynamic_8idl.html',1,'']]],
-  ['dynamicresultset_2eidl_260',['DynamicResultSet.idl',['../DynamicResultSet_8idl.html',1,'']]]
+  ['dump_2eidl_255',['Dump.idl',['../Dump_8idl.html',1,'']]],
+  ['duplexmode_2eidl_256',['DuplexMode.idl',['../DuplexMode_8idl.html',1,'']]],
+  ['duplicatecommandidentifierexception_2eidl_257',['DuplicateCommandIdentifierException.idl',['../DuplicateCommandIdentifierException_8idl.html',1,'']]],
+  ['duplicateproviderexception_2eidl_258',['DuplicateProviderException.idl',['../DuplicateProviderException_8idl.html',1,'']]],
+  ['duration_2eidl_259',['Duration.idl',['../Duration_8idl.html',1,'']]],
+  ['dynamic_2eidl_260',['Dynamic.idl',['../Dynamic_8idl.html',1,'']]],
+  ['dynamicresultset_2eidl_261',['DynamicResultSet.idl',['../DynamicResultSet_8idl.html',1,'']]]
 ];
