@@ -104,5 +104,6 @@ var searchData=
   ['loggerpool_2eidl_101',['LoggerPool.idl',['../LoggerPool_8idl.html',1,'']]],
   ['logictargetmodel_2eidl_102',['LogicTargetModel.idl',['../LogicTargetModel_8idl.html',1,'']]],
   ['loglevel_2eidl_103',['LogLevel.idl',['../LogLevel_8idl.html',1,'']]],
-  ['logrecord_2eidl_104',['LogRecord.idl',['../LogRecord_8idl.html',1,'']]]
+  ['logrecord_2eidl_104',['LogRecord.idl',['../LogRecord_8idl.html',1,'']]],
+  ['lokclipboard_2eidl_105',['LokClipboard.idl',['../LokClipboard_8idl.html',1,'']]]
 ];
