@@ -67,35 +67,34 @@ var searchData=
   ['model_2eidl_64',['Model.idl',['../Model_8idl.html',1,'']]],
   ['modeldependent_2eidl_65',['ModelDependent.idl',['../ModelDependent_8idl.html',1,'']]],
   ['moduleacceleratorconfiguration_2eidl_66',['ModuleAcceleratorConfiguration.idl',['../ModuleAcceleratorConfiguration_8idl.html',1,'']]],
-  ['modulecontroller_2eidl_67',['ModuleController.idl',['../ModuleController_8idl.html',1,'']]],
-  ['moduledispatcher_2eidl_68',['ModuleDispatcher.idl',['../drawing_2ModuleDispatcher_8idl.html',1,'(Global Namespace)'],['../text_2ModuleDispatcher_8idl.html',1,'(Global Namespace)']]],
-  ['moduleinfo_2eidl_69',['ModuleInfo.idl',['../ModuleInfo_8idl.html',1,'']]],
-  ['modulemanager_2eidl_70',['ModuleManager.idl',['../ModuleManager_8idl.html',1,'']]],
-  ['modules_2eidl_71',['modules.idl',['../udkapi_2com_2sun_2star_2modules_8idl.html',1,'(Global Namespace)'],['../offapi_2com_2sun_2star_2modules_8idl.html',1,'(Global Namespace)'],['../offapi_2com_2sun_2star_2report_2modules_8idl.html',1,'(Global Namespace)'],['../offapi_2com_2sun_2star_2form_2modules_8idl.html',1,'(Global Namespace)'],['../offapi_2com_2sun_2star_2drawing_2modules_8idl.html',1,'(Global Namespace)']]],
-  ['modulesizeexceededrequest_2eidl_72',['ModuleSizeExceededRequest.idl',['../ModuleSizeExceededRequest_8idl.html',1,'']]],
-  ['moduletype_2eidl_73',['ModuleType.idl',['../ModuleType_8idl.html',1,'']]],
-  ['moduleuicategorydescription_2eidl_74',['ModuleUICategoryDescription.idl',['../ModuleUICategoryDescription_8idl.html',1,'']]],
-  ['moduleuicommanddescription_2eidl_75',['ModuleUICommandDescription.idl',['../ModuleUICommandDescription_8idl.html',1,'']]],
-  ['moduleuiconfigurationmanager_2eidl_76',['ModuleUIConfigurationManager.idl',['../ModuleUIConfigurationManager_8idl.html',1,'']]],
-  ['moduleuiconfigurationmanagersupplier_2eidl_77',['ModuleUIConfigurationManagerSupplier.idl',['../ModuleUIConfigurationManagerSupplier_8idl.html',1,'']]],
-  ['modulewindowstateconfiguration_2eidl_78',['ModuleWindowStateConfiguration.idl',['../ModuleWindowStateConfiguration_8idl.html',1,'']]],
-  ['month_2eidl_79',['Month.idl',['../Month_8idl.html',1,'']]],
-  ['months_2eidl_80',['Months.idl',['../Months_8idl.html',1,'']]],
-  ['mousebutton_2eidl_81',['MouseButton.idl',['../MouseButton_8idl.html',1,'']]],
-  ['mouseevent_2eidl_82',['MouseEvent.idl',['../MouseEvent_8idl.html',1,'']]],
-  ['mousewheelbehavior_2eidl_83',['MouseWheelBehavior.idl',['../MouseWheelBehavior_8idl.html',1,'']]],
-  ['movedirection_2eidl_84',['MoveDirection.idl',['../MoveDirection_8idl.html',1,'']]],
-  ['movingaverageregressioncurve_2eidl_85',['MovingAverageRegressionCurve.idl',['../MovingAverageRegressionCurve_8idl.html',1,'']]],
-  ['movingaveragetype_2eidl_86',['MovingAverageType.idl',['../MovingAverageType_8idl.html',1,'']]],
-  ['mozillabootstrap_2eidl_87',['MozillaBootstrap.idl',['../MozillaBootstrap_8idl.html',1,'']]],
-  ['mozillaproducttype_2eidl_88',['MozillaProductType.idl',['../MozillaProductType_8idl.html',1,'']]],
-  ['msaaservice_2eidl_89',['MSAAService.idl',['../MSAAService_8idl.html',1,'']]],
-  ['msoleobjectsystemcreator_2eidl_90',['MSOLEObjectSystemCreator.idl',['../MSOLEObjectSystemCreator_8idl.html',1,'']]],
-  ['mtfrenderer_2eidl_91',['MtfRenderer.idl',['../MtfRenderer_8idl.html',1,'']]],
-  ['multilayerstratum_2eidl_92',['MultiLayerStratum.idl',['../MultiLayerStratum_8idl.html',1,'']]],
-  ['multiplecharsoutputexception_2eidl_93',['MultipleCharsOutputException.idl',['../MultipleCharsOutputException_8idl.html',1,'']]],
-  ['multiservicefactory_2eidl_94',['MultiServiceFactory.idl',['../MultiServiceFactory_8idl.html',1,'']]],
-  ['multistratumbackend_2eidl_95',['MultiStratumBackend.idl',['../MultiStratumBackend_8idl.html',1,'']]],
-  ['mutabletreedatamodel_2eidl_96',['MutableTreeDataModel.idl',['../MutableTreeDataModel_8idl.html',1,'']]],
-  ['mutabletreenode_2eidl_97',['MutableTreeNode.idl',['../MutableTreeNode_8idl.html',1,'']]]
+  ['moduledispatcher_2eidl_67',['ModuleDispatcher.idl',['../drawing_2ModuleDispatcher_8idl.html',1,'(Global Namespace)'],['../text_2ModuleDispatcher_8idl.html',1,'(Global Namespace)']]],
+  ['moduleinfo_2eidl_68',['ModuleInfo.idl',['../ModuleInfo_8idl.html',1,'']]],
+  ['modulemanager_2eidl_69',['ModuleManager.idl',['../ModuleManager_8idl.html',1,'']]],
+  ['modules_2eidl_70',['modules.idl',['../udkapi_2com_2sun_2star_2modules_8idl.html',1,'(Global Namespace)'],['../offapi_2com_2sun_2star_2report_2modules_8idl.html',1,'(Global Namespace)'],['../offapi_2com_2sun_2star_2modules_8idl.html',1,'(Global Namespace)'],['../offapi_2com_2sun_2star_2drawing_2modules_8idl.html',1,'(Global Namespace)'],['../offapi_2com_2sun_2star_2form_2modules_8idl.html',1,'(Global Namespace)']]],
+  ['modulesizeexceededrequest_2eidl_71',['ModuleSizeExceededRequest.idl',['../ModuleSizeExceededRequest_8idl.html',1,'']]],
+  ['moduletype_2eidl_72',['ModuleType.idl',['../ModuleType_8idl.html',1,'']]],
+  ['moduleuicategorydescription_2eidl_73',['ModuleUICategoryDescription.idl',['../ModuleUICategoryDescription_8idl.html',1,'']]],
+  ['moduleuicommanddescription_2eidl_74',['ModuleUICommandDescription.idl',['../ModuleUICommandDescription_8idl.html',1,'']]],
+  ['moduleuiconfigurationmanager_2eidl_75',['ModuleUIConfigurationManager.idl',['../ModuleUIConfigurationManager_8idl.html',1,'']]],
+  ['moduleuiconfigurationmanagersupplier_2eidl_76',['ModuleUIConfigurationManagerSupplier.idl',['../ModuleUIConfigurationManagerSupplier_8idl.html',1,'']]],
+  ['modulewindowstateconfiguration_2eidl_77',['ModuleWindowStateConfiguration.idl',['../ModuleWindowStateConfiguration_8idl.html',1,'']]],
+  ['month_2eidl_78',['Month.idl',['../Month_8idl.html',1,'']]],
+  ['months_2eidl_79',['Months.idl',['../Months_8idl.html',1,'']]],
+  ['mousebutton_2eidl_80',['MouseButton.idl',['../MouseButton_8idl.html',1,'']]],
+  ['mouseevent_2eidl_81',['MouseEvent.idl',['../MouseEvent_8idl.html',1,'']]],
+  ['mousewheelbehavior_2eidl_82',['MouseWheelBehavior.idl',['../MouseWheelBehavior_8idl.html',1,'']]],
+  ['movedirection_2eidl_83',['MoveDirection.idl',['../MoveDirection_8idl.html',1,'']]],
+  ['movingaverageregressioncurve_2eidl_84',['MovingAverageRegressionCurve.idl',['../MovingAverageRegressionCurve_8idl.html',1,'']]],
+  ['movingaveragetype_2eidl_85',['MovingAverageType.idl',['../MovingAverageType_8idl.html',1,'']]],
+  ['mozillabootstrap_2eidl_86',['MozillaBootstrap.idl',['../MozillaBootstrap_8idl.html',1,'']]],
+  ['mozillaproducttype_2eidl_87',['MozillaProductType.idl',['../MozillaProductType_8idl.html',1,'']]],
+  ['msaaservice_2eidl_88',['MSAAService.idl',['../MSAAService_8idl.html',1,'']]],
+  ['msoleobjectsystemcreator_2eidl_89',['MSOLEObjectSystemCreator.idl',['../MSOLEObjectSystemCreator_8idl.html',1,'']]],
+  ['mtfrenderer_2eidl_90',['MtfRenderer.idl',['../MtfRenderer_8idl.html',1,'']]],
+  ['multilayerstratum_2eidl_91',['MultiLayerStratum.idl',['../MultiLayerStratum_8idl.html',1,'']]],
+  ['multiplecharsoutputexception_2eidl_92',['MultipleCharsOutputException.idl',['../MultipleCharsOutputException_8idl.html',1,'']]],
+  ['multiservicefactory_2eidl_93',['MultiServiceFactory.idl',['../MultiServiceFactory_8idl.html',1,'']]],
+  ['multistratumbackend_2eidl_94',['MultiStratumBackend.idl',['../MultiStratumBackend_8idl.html',1,'']]],
+  ['mutabletreedatamodel_2eidl_95',['MutableTreeDataModel.idl',['../MutableTreeDataModel_8idl.html',1,'']]],
+  ['mutabletreenode_2eidl_96',['MutableTreeNode.idl',['../MutableTreeNode_8idl.html',1,'']]]
 ];
